@@ -1,4 +1,5 @@
 from os import environ, getenv
+from pathlib import Path
 import sys
 
 from django.core.exceptions import ImproperlyConfigured
@@ -9,13 +10,30 @@ from envconfig.parser import EnvParser
 from envconfig.setting_types import get_setting_types
 from envconfig import utils
 
-extra_paths = utils.find_paths_to_project_root()
+# Based on the command line arguments try and infer the project name and
+# the path to the base directory (to look for .env)
+project_name = None
+extra_paths = []
+for arg in sys.argv:
+    if arg.endswith('.asgi:application') or arg.endswith('.wsgi'):
+        project_name = arg.split('.')[0]
+        try:
+            extra_paths.append(utils.get_base_dir(project_name))
+        except ModuleNotFoundError:
+            pass
+    if arg.endswith('manage.py'):
+        base_dir = Path(arg).parent.absolute()
+        project_name = utils.find_project_name(base_dir)
+        extra_paths.append(base_dir)
+
 load_dotenv(dotenv_path=find_dotenv(extra_paths=extra_paths))
 
-project_name = getenv('DJANGO_PROJECT')
+project_name = getenv('DJANGO_PROJECT', project_name)
 if not project_name:
-    raise ImproperlyConfigured("Required environment variable "
-                               "'DJANGO_PROJECT' not found.")
+    raise ImproperlyConfigured(
+        "Could not find Django project (i.e. module with wsgi.py or asgi.py). "
+        "Please set environment variable 'DJANGO_PROJECT'."
+    )
 
 # Generate default settings and values from startproject template settings.py
 settings = utils.get_template_settings(project_name)
@@ -48,19 +66,33 @@ for name in envsetting_names:
                 f"Error: {str(e)}. Valid types include: '{types_str}'."
             )
 
+# django-envconfig settings
+settings['INSTALLED_APPS'] = utils.modify_list(
+    settings['INSTALLED_APPS'],
+    add=settings.get('ADD_INSTALLED_APPS', []),
+    remove=settings.get('REMOVE_INSTALLED_APPS', [])
+)
+# Respect that MIDDLEWARE can be None
+if settings['MIDDLEWARE'] is not None or settings.get('ADD_MIDDLEWARE'):
+    settings['MIDDLEWARE'] = utils.modify_list(
+        settings.get('MIDDLEWARE') or [],
+        add=settings.get('ADD_MIDDLEWARE', []),
+        remove=settings.get('REMOVE_MIDDLEWARE', [])
+    )
+
 # PostgreSQL
 # https://www.postgresql.org/docs/current/libpq-envars.html
-if 'DATABASES' not in settings and getenv('PGDATABASE'):
+if 'PGDATABASE' in settings:
     settings['DATABASES'] = {
         'default': {
             'ENGINE': 'django.db.backends.postgresql',
-            'NAME': getenv('PGDATABASE'),
-            'USER': getenv('PGUSER', ''),
-            'PASSWORD': getenv('PGPASSWORD', ''),
-            'HOST': getenv('PGHOST', ''),
-            'PORT': getenv('PGPORT', ''),
+            'NAME': settings.get('PGDATABASE'),
+            'USER': settings.pop('PGUSER', ''),
+            'PASSWORD': settings.pop('PGPASSWORD', ''),
+            'HOST': settings.pop('PGHOST', ''),
+            'PORT': settings.pop('PGPORT', ''),
             'TEST': {
-                'NAME': 'test_' + getenv('PGDATABASE', ''),
+                'NAME': 'test_' + settings.pop('PGDATABASE'),
             }
         }
     }
